aboutsummaryrefslogtreecommitdiff
path: root/lib/Analysis/DebugInfo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Analysis/DebugInfo.cpp')
-rw-r--r--lib/Analysis/DebugInfo.cpp14
1 files changed, 8 insertions, 6 deletions
diff --git a/lib/Analysis/DebugInfo.cpp b/lib/Analysis/DebugInfo.cpp
index 7dc652fb7b..bd81314f46 100644
--- a/lib/Analysis/DebugInfo.cpp
+++ b/lib/Analysis/DebugInfo.cpp
@@ -1078,9 +1078,10 @@ Instruction *DIFactory::InsertDeclare(Value *Storage, DIVariable D,
return CallInst::Create(DeclareFn, Args, Args+2, "", InsertAtEnd);
}
-/// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
- Instruction *InsertBefore) {
+/// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+Instruction *DIFactory::InsertDbgValueIntrinsic(Value *V, Value *Offset,
+ DIVariable D,
+ Instruction *InsertBefore) {
assert(V && "no value passed to dbg.value");
assert(Offset->getType() == Type::getInt64Ty(V->getContext()) &&
"offset must be i64");
@@ -1093,9 +1094,10 @@ Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
return CallInst::Create(ValueFn, Args, Args+3, "", InsertBefore);
}
-/// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
- BasicBlock *InsertAtEnd) {
+/// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+Instruction *DIFactory::InsertDbgValueIntrinsic(Value *V, Value *Offset,
+ DIVariable D,
+ BasicBlock *InsertAtEnd) {
assert(V && "no value passed to dbg.value");
assert(Offset->getType() == Type::getInt64Ty(V->getContext()) &&
"offset must be i64");